@@ -8,7 +8,11 @@ Usage::
     from mypy_boto3_transfer import (
         Client,
         ListAccessesPaginator,
+        ListAgreementsPaginator,
+        ListCertificatesPaginator,
+        ListConnectorsPaginator,
         ListExecutionsPaginator,
+        ListProfilesPaginator,
         ListSecurityPoliciesPaginator,
         ListServersPaginator,
         ListTagsForResourcePaginator,
@@ -26,7 +30,11 @@ Usage::
     server_online_waiter: ServerOnlineWaiter = client.get_waiter("server_online")
 
     list_accesses_paginator: ListAccessesPaginator = client.get_paginator("list_accesses")
+    list_agreements_paginator: ListAgreementsPaginator = client.get_paginator("list_agreements")
+    list_certificates_paginator: ListCertificatesPaginator = client.get_paginator("list_certificates")
+    list_connectors_paginator: ListConnectorsPaginator = client.get_paginator("list_connectors")
     list_executions_paginator: ListExecutionsPaginator = client.get_paginator("list_executions")
+    list_profiles_paginator: ListProfilesPaginator = client.get_paginator("list_profiles")
     list_security_policies_paginator: ListSecurityPoliciesPaginator = client.get_paginator("list_security_policies")
     list_servers_paginator: ListServersPaginator = client.get_paginator("list_servers")
     list_tags_for_resource_paginator: ListTagsForResourcePaginator = client.get_paginator("list_tags_for_resource")
@@ -37,7 +45,11 @@ Usage::
 from .client import TransferClient
 from .paginator import (
     ListAccessesPaginator,
+    ListAgreementsPaginator,
+    ListCertificatesPaginator,
+    ListConnectorsPaginator,
     ListExecutionsPaginator,
+    ListProfilesPaginator,
     ListSecurityPoliciesPaginator,
     ListServersPaginator,
     ListTagsForResourcePaginator,
@@ -52,7 +64,11 @@ Client = TransferClient
 __all__ = (
     "Client",
     "ListAccessesPaginator",
+    "ListAgreementsPaginator",
+    "ListCertificatesPaginator",
+    "ListConnectorsPaginator",
     "ListExecutionsPaginator",
+    "ListProfilesPaginator",
     "ListSecurityPoliciesPaginator",
     "ListServersPaginator",
     "ListTagsForResourcePaginator",
