@@ -14,21 +14,29 @@ Usage::
     ```
 """
 import sys
-from typing import Any, Dict, Mapping, Sequence, Type, overload
+from datetime import datetime
+from typing import Any, Dict, Mapping, Sequence, Type, Union, overload
 
 from botocore.client import BaseClient, ClientMeta
 
 from .literals import (
+    AgreementStatusTypeType,
+    CertificateUsageTypeType,
     CustomStepStatusType,
     DomainType,
     EndpointTypeType,
     HomeDirectoryTypeType,
     IdentityProviderTypeType,
+    ProfileTypeType,
     ProtocolType,
 )
 from .paginator import (
     ListAccessesPaginator,
+    ListAgreementsPaginator,
+    ListCertificatesPaginator,
+    ListConnectorsPaginator,
     ListExecutionsPaginator,
+    ListProfilesPaginator,
     ListSecurityPoliciesPaginator,
     ListServersPaginator,
     ListTagsForResourcePaginator,
@@ -36,12 +44,21 @@ from .paginator import (
     ListWorkflowsPaginator,
 )
 from .type_defs import (
+    As2ConnectorConfigTypeDef,
     CreateAccessResponseTypeDef,
+    CreateAgreementResponseTypeDef,
+    CreateConnectorResponseTypeDef,
+    CreateProfileResponseTypeDef,
     CreateServerResponseTypeDef,
     CreateUserResponseTypeDef,
     CreateWorkflowResponseTypeDef,
     DescribeAccessResponseTypeDef,
+    DescribeAgreementResponseTypeDef,
+    DescribeCertificateResponseTypeDef,
+    DescribeConnectorResponseTypeDef,
     DescribeExecutionResponseTypeDef,
+    DescribeHostKeyResponseTypeDef,
+    DescribeProfileResponseTypeDef,
     DescribeSecurityPolicyResponseTypeDef,
     DescribeServerResponseTypeDef,
     DescribeUserResponseTypeDef,
@@ -50,9 +67,16 @@ from .type_defs import (
     EndpointDetailsTypeDef,
     HomeDirectoryMapEntryTypeDef,
     IdentityProviderDetailsTypeDef,
+    ImportCertificateResponseTypeDef,
+    ImportHostKeyResponseTypeDef,
     ImportSshPublicKeyResponseTypeDef,
     ListAccessesResponseTypeDef,
+    ListAgreementsResponseTypeDef,
+    ListCertificatesResponseTypeDef,
+    ListConnectorsResponseTypeDef,
     ListExecutionsResponseTypeDef,
+    ListHostKeysResponseTypeDef,
+    ListProfilesResponseTypeDef,
     ListSecurityPoliciesResponseTypeDef,
     ListServersResponseTypeDef,
     ListTagsForResourceResponseTypeDef,
@@ -60,9 +84,15 @@ from .type_defs import (
     ListWorkflowsResponseTypeDef,
     PosixProfileTypeDef,
     ProtocolDetailsTypeDef,
+    StartFileTransferResponseTypeDef,
     TagTypeDef,
     TestIdentityProviderResponseTypeDef,
     UpdateAccessResponseTypeDef,
+    UpdateAgreementResponseTypeDef,
+    UpdateCertificateResponseTypeDef,
+    UpdateConnectorResponseTypeDef,
+    UpdateHostKeyResponseTypeDef,
+    UpdateProfileResponseTypeDef,
     UpdateServerResponseTypeDef,
     UpdateUserResponseTypeDef,
     WorkflowDetailsTypeDef,
@@ -147,13 +177,64 @@ class TransferClient(BaseClient):
     ) -> CreateAccessResponseTypeDef:
         """
         Used by administrators to choose which groups in the directory should have
-        access to upload and download files over the enabled protocols using Amazon Web
-        Services Transfer Family.
+        access to upload and download files over the enabled protocols using Transfer
+        Family.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.create_access)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/client/#create_access)
         """
 
+    def create_agreement(
+        self,
+        *,
+        ServerId: str,
+        LocalProfileId: str,
+        PartnerProfileId: str,
+        BaseDirectory: str,
+        AccessRole: str,
+        Description: str = ...,
+        Status: AgreementStatusTypeType = ...,
+        Tags: Sequence[TagTypeDef] = ...
+    ) -> CreateAgreementResponseTypeDef:
+        """
+        Creates an agreement.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.create_agreement)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/client/#create_agreement)
+        """
+
+    def create_connector(
+        self,
+        *,
+        Url: str,
+        As2Config: As2ConnectorConfigTypeDef,
+        AccessRole: str,
+        LoggingRole: str = ...,
+        Tags: Sequence[TagTypeDef] = ...
+    ) -> CreateConnectorResponseTypeDef:
+        """
+        Creates the connector, which captures the parameters for an outbound connection
+        for the AS2 protocol.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.create_connector)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/client/#create_connector)
+        """
+
+    def create_profile(
+        self,
+        *,
+        As2Id: str,
+        ProfileType: ProfileTypeType,
+        CertificateIds: Sequence[str] = ...,
+        Tags: Sequence[TagTypeDef] = ...
+    ) -> CreateProfileResponseTypeDef:
+        """
+        Creates the local or partner profile to use for AS2 transfers.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.create_profile)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/client/#create_profile)
+        """
+
     def create_server(
         self,
         *,
@@ -228,6 +309,46 @@ class TransferClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/client/#delete_access)
         """
 
+    def delete_agreement(self, *, AgreementId: str, ServerId: str) -> EmptyResponseMetadataTypeDef:
+        """
+        Delete the agreement that's specified in the provided `AgreementId` .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.delete_agreement)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/client/#delete_agreement)
+        """
+
+    def delete_certificate(self, *, CertificateId: str) -> EmptyResponseMetadataTypeDef:
+        """
+        Deletes the certificate that's specified in the `CertificateId` parameter.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.delete_certificate)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/client/#delete_certificate)
+        """
+
+    def delete_connector(self, *, ConnectorId: str) -> EmptyResponseMetadataTypeDef:
+        """
+        Deletes the agreement that's specified in the provided `ConnectorId` .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.delete_connector)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/client/#delete_connector)
+        """
+
+    def delete_host_key(self, *, ServerId: str, HostKeyId: str) -> EmptyResponseMetadataTypeDef:
+        """
+        Deletes the host key that's specified in the `HoskKeyId` parameter.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.delete_host_key)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/client/#delete_host_key)
+        """
+
+    def delete_profile(self, *, ProfileId: str) -> EmptyResponseMetadataTypeDef:
+        """
+        Deletes the profile that's specified in the `ProfileId` parameter.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.delete_profile)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/client/#delete_profile)
+        """
+
     def delete_server(self, *, ServerId: str) -> EmptyResponseMetadataTypeDef:
         """
         Deletes the file transfer protocol-enabled server that you specify.
@@ -266,12 +387,40 @@ class TransferClient(BaseClient):
     def describe_access(self, *, ServerId: str, ExternalId: str) -> DescribeAccessResponseTypeDef:
         """
         Describes the access that is assigned to the specific file transfer protocol-
-        enabled server, as identified by its `ServerId` property and its `ExternalID` .
+        enabled server, as identified by its `ServerId` property and its `ExternalId` .
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.describe_access)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/client/#describe_access)
         """
 
+    def describe_agreement(
+        self, *, AgreementId: str, ServerId: str
+    ) -> DescribeAgreementResponseTypeDef:
+        """
+        Describes the agreement that's identified by the `AgreementId` .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.describe_agreement)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/client/#describe_agreement)
+        """
+
+    def describe_certificate(self, *, CertificateId: str) -> DescribeCertificateResponseTypeDef:
+        """
+        Describes the certificate that's identified by the `CertificateId` .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.describe_certificate)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/client/#describe_certificate)
+        """
+
+    def describe_connector(self, *, ConnectorId: str) -> DescribeConnectorResponseTypeDef:
+        """
+        Describes the connector that's identified by the `ConnectorId.` See also: [AWS
+        API
+        Documentation](https://docs.aws.amazon.com/goto/WebAPI/transfer-2018-11-05/DescribeConnector).
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.describe_connector)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/client/#describe_connector)
+        """
+
     def describe_execution(
         self, *, ExecutionId: str, WorkflowId: str
     ) -> DescribeExecutionResponseTypeDef:
@@ -283,6 +432,23 @@ class TransferClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/client/#describe_execution)
         """
 
+    def describe_host_key(self, *, ServerId: str, HostKeyId: str) -> DescribeHostKeyResponseTypeDef:
+        """
+        Returns the details of the host key that's specified by the `HostKeyId` and
+        `ServerId` .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.describe_host_key)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/client/#describe_host_key)
+        """
+
+    def describe_profile(self, *, ProfileId: str) -> DescribeProfileResponseTypeDef:
+        """
+        Returns the details of the profile that's specified by the `ProfileId` .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.describe_profile)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/client/#describe_profile)
+        """
+
     def describe_security_policy(
         self, *, SecurityPolicyName: str
     ) -> DescribeSecurityPolicyResponseTypeDef:
@@ -334,6 +500,41 @@ class TransferClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/client/#generate_presigned_url)
         """
 
+    def import_certificate(
+        self,
+        *,
+        Usage: CertificateUsageTypeType,
+        Certificate: str,
+        CertificateChain: str = ...,
+        PrivateKey: str = ...,
+        ActiveDate: Union[datetime, str] = ...,
+        InactiveDate: Union[datetime, str] = ...,
+        Description: str = ...,
+        Tags: Sequence[TagTypeDef] = ...
+    ) -> ImportCertificateResponseTypeDef:
+        """
+        Imports the signing and encryption certificates that you need to create local
+        (AS2) profiles and partner profiles.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.import_certificate)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/client/#import_certificate)
+        """
+
+    def import_host_key(
+        self,
+        *,
+        ServerId: str,
+        HostKeyBody: str,
+        Description: str = ...,
+        Tags: Sequence[TagTypeDef] = ...
+    ) -> ImportHostKeyResponseTypeDef:
+        """
+        Adds a host key to the server that's specified by the `ServerId` parameter.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.import_host_key)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/client/#import_host_key)
+        """
+
     def import_ssh_public_key(
         self, *, ServerId: str, SshPublicKeyBody: str, UserName: str
     ) -> ImportSshPublicKeyResponseTypeDef:
@@ -356,6 +557,38 @@ class TransferClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/client/#list_accesses)
         """
 
+    def list_agreements(
+        self, *, ServerId: str, MaxResults: int = ..., NextToken: str = ...
+    ) -> ListAgreementsResponseTypeDef:
+        """
+        Returns a list of the agreements for the server that's identified by the
+        `ServerId` that you supply.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.list_agreements)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/client/#list_agreements)
+        """
+
+    def list_certificates(
+        self, *, MaxResults: int = ..., NextToken: str = ...
+    ) -> ListCertificatesResponseTypeDef:
+        """
+        Returns a list of the current certificates that have been imported into Transfer
+        Family.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.list_certificates)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/client/#list_certificates)
+        """
+
+    def list_connectors(
+        self, *, MaxResults: int = ..., NextToken: str = ...
+    ) -> ListConnectorsResponseTypeDef:
+        """
+        Lists the connectors for the specified Region.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.list_connectors)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/client/#list_connectors)
+        """
+
     def list_executions(
         self, *, WorkflowId: str, MaxResults: int = ..., NextToken: str = ...
     ) -> ListExecutionsResponseTypeDef:
@@ -366,6 +599,27 @@ class TransferClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/client/#list_executions)
         """
 
+    def list_host_keys(
+        self, *, ServerId: str, MaxResults: int = ..., NextToken: str = ...
+    ) -> ListHostKeysResponseTypeDef:
+        """
+        Returns a list of host keys for the server that's specified by the `ServerId`
+        parameter.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.list_host_keys)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/client/#list_host_keys)
+        """
+
+    def list_profiles(
+        self, *, MaxResults: int = ..., NextToken: str = ..., ProfileType: ProfileTypeType = ...
+    ) -> ListProfilesResponseTypeDef:
+        """
+        Returns a list of the profiles for your system.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.list_profiles)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/client/#list_profiles)
+        """
+
     def list_security_policies(
         self, *, MaxResults: int = ..., NextToken: str = ...
     ) -> ListSecurityPoliciesResponseTypeDef:
@@ -430,6 +684,16 @@ class TransferClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/client/#send_workflow_step_state)
         """
 
+    def start_file_transfer(
+        self, *, ConnectorId: str, SendFilePaths: Sequence[str]
+    ) -> StartFileTransferResponseTypeDef:
+        """
+        Begins an outbound file transfer to a remote AS2 server.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.start_file_transfer)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/client/#start_file_transfer)
+        """
+
     def start_server(self, *, ServerId: str) -> EmptyResponseMetadataTypeDef:
         """
         Changes the state of a file transfer protocol-enabled server from `OFFLINE` to
@@ -504,6 +768,77 @@ class TransferClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/client/#update_access)
         """
 
+    def update_agreement(
+        self,
+        *,
+        AgreementId: str,
+        ServerId: str,
+        Description: str = ...,
+        Status: AgreementStatusTypeType = ...,
+        LocalProfileId: str = ...,
+        PartnerProfileId: str = ...,
+        BaseDirectory: str = ...,
+        AccessRole: str = ...
+    ) -> UpdateAgreementResponseTypeDef:
+        """
+        Updates some of the parameters for an existing agreement.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.update_agreement)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/client/#update_agreement)
+        """
+
+    def update_certificate(
+        self,
+        *,
+        CertificateId: str,
+        ActiveDate: Union[datetime, str] = ...,
+        InactiveDate: Union[datetime, str] = ...,
+        Description: str = ...
+    ) -> UpdateCertificateResponseTypeDef:
+        """
+        Updates the active and inactive dates for a certificate.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.update_certificate)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/client/#update_certificate)
+        """
+
+    def update_connector(
+        self,
+        *,
+        ConnectorId: str,
+        Url: str = ...,
+        As2Config: As2ConnectorConfigTypeDef = ...,
+        AccessRole: str = ...,
+        LoggingRole: str = ...
+    ) -> UpdateConnectorResponseTypeDef:
+        """
+        Updates some of the parameters for an existing connector.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.update_connector)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/client/#update_connector)
+        """
+
+    def update_host_key(
+        self, *, ServerId: str, HostKeyId: str, Description: str
+    ) -> UpdateHostKeyResponseTypeDef:
+        """
+        Updates the description for the host key that's specified by the `ServerId` and
+        `HostKeyId` parameters.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.update_host_key)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/client/#update_host_key)
+        """
+
+    def update_profile(
+        self, *, ProfileId: str, CertificateIds: Sequence[str] = ...
+    ) -> UpdateProfileResponseTypeDef:
+        """
+        Updates some of the parameters for an existing profile.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.update_profile)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/client/#update_profile)
+        """
+
     def update_server(
         self,
         *,
@@ -555,6 +890,29 @@ class TransferClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/client/#get_paginator)
         """
 
+    @overload
+    def get_paginator(self, operation_name: Literal["list_agreements"]) -> ListAgreementsPaginator:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/client/#get_paginator)
+        """
+
+    @overload
+    def get_paginator(
+        self, operation_name: Literal["list_certificates"]
+    ) -> ListCertificatesPaginator:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/client/#get_paginator)
+        """
+
+    @overload
+    def get_paginator(self, operation_name: Literal["list_connectors"]) -> ListConnectorsPaginator:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/client/#get_paginator)
+        """
+
     @overload
     def get_paginator(self, operation_name: Literal["list_executions"]) -> ListExecutionsPaginator:
         """
@@ -562,6 +920,13 @@ class TransferClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/client/#get_paginator)
         """
 
+    @overload
+    def get_paginator(self, operation_name: Literal["list_profiles"]) -> ListProfilesPaginator:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/client/#get_paginator)
+        """
+
     @overload
     def get_paginator(
         self, operation_name: Literal["list_security_policies"]
