@@ -6,9 +6,9 @@ Type annotations for transfer service literal definitions.
 Usage::
 
     ```python
-    from mypy_boto3_transfer.literals import CustomStepStatusType
+    from mypy_boto3_transfer.literals import AgreementStatusTypeType
 
-    data: CustomStepStatusType = "FAILURE"
+    data: AgreementStatusTypeType = "ACTIVE"
     ```
 """
 import sys
@@ -20,25 +20,40 @@ else:
 
 
 __all__ = (
+    "AgreementStatusTypeType",
+    "As2TransportType",
+    "CertificateStatusTypeType",
+    "CertificateTypeType",
+    "CertificateUsageTypeType",
+    "CompressionEnumType",
     "CustomStepStatusType",
     "DomainType",
+    "EncryptionAlgType",
     "EndpointTypeType",
     "ExecutionErrorTypeType",
     "ExecutionStatusType",
     "HomeDirectoryTypeType",
     "IdentityProviderTypeType",
     "ListAccessesPaginatorName",
+    "ListAgreementsPaginatorName",
+    "ListCertificatesPaginatorName",
+    "ListConnectorsPaginatorName",
     "ListExecutionsPaginatorName",
+    "ListProfilesPaginatorName",
     "ListSecurityPoliciesPaginatorName",
     "ListServersPaginatorName",
     "ListTagsForResourcePaginatorName",
     "ListUsersPaginatorName",
     "ListWorkflowsPaginatorName",
+    "MdnResponseType",
+    "MdnSigningAlgType",
     "OverwriteExistingType",
+    "ProfileTypeType",
     "ProtocolType",
     "ServerOfflineWaiterName",
     "ServerOnlineWaiterName",
     "SetStatOptionType",
+    "SigningAlgType",
     "StateType",
     "TlsSessionResumptionModeType",
     "WorkflowStepTypeType",
@@ -51,8 +66,15 @@ __all__ = (
 )
 
 
+AgreementStatusTypeType = Literal["ACTIVE", "INACTIVE"]
+As2TransportType = Literal["HTTP"]
+CertificateStatusTypeType = Literal["ACTIVE", "INACTIVE", "PENDING_ROTATION"]
+CertificateTypeType = Literal["CERTIFICATE", "CERTIFICATE_WITH_PRIVATE_KEY"]
+CertificateUsageTypeType = Literal["ENCRYPTION", "SIGNING"]
+CompressionEnumType = Literal["DISABLED", "ZLIB"]
 CustomStepStatusType = Literal["FAILURE", "SUCCESS"]
 DomainType = Literal["EFS", "S3"]
+EncryptionAlgType = Literal["AES128_CBC", "AES192_CBC", "AES256_CBC", "NONE"]
 EndpointTypeType = Literal["PUBLIC", "VPC", "VPC_ENDPOINT"]
 ExecutionErrorTypeType = Literal[
     "ALREADY_EXISTS",
@@ -70,17 +92,25 @@ IdentityProviderTypeType = Literal[
     "API_GATEWAY", "AWS_DIRECTORY_SERVICE", "AWS_LAMBDA", "SERVICE_MANAGED"
 ]
 ListAccessesPaginatorName = Literal["list_accesses"]
+ListAgreementsPaginatorName = Literal["list_agreements"]
+ListCertificatesPaginatorName = Literal["list_certificates"]
+ListConnectorsPaginatorName = Literal["list_connectors"]
 ListExecutionsPaginatorName = Literal["list_executions"]
+ListProfilesPaginatorName = Literal["list_profiles"]
 ListSecurityPoliciesPaginatorName = Literal["list_security_policies"]
 ListServersPaginatorName = Literal["list_servers"]
 ListTagsForResourcePaginatorName = Literal["list_tags_for_resource"]
 ListUsersPaginatorName = Literal["list_users"]
 ListWorkflowsPaginatorName = Literal["list_workflows"]
+MdnResponseType = Literal["NONE", "SYNC"]
+MdnSigningAlgType = Literal["DEFAULT", "NONE", "SHA1", "SHA256", "SHA384", "SHA512"]
 OverwriteExistingType = Literal["FALSE", "TRUE"]
-ProtocolType = Literal["FTP", "FTPS", "SFTP"]
+ProfileTypeType = Literal["LOCAL", "PARTNER"]
+ProtocolType = Literal["AS2", "FTP", "FTPS", "SFTP"]
 ServerOfflineWaiterName = Literal["server_offline"]
 ServerOnlineWaiterName = Literal["server_online"]
 SetStatOptionType = Literal["DEFAULT", "ENABLE_NO_OP"]
+SigningAlgType = Literal["NONE", "SHA1", "SHA256", "SHA384", "SHA512"]
 StateType = Literal["OFFLINE", "ONLINE", "STARTING", "START_FAILED", "STOPPING", "STOP_FAILED"]
 TlsSessionResumptionModeType = Literal["DISABLED", "ENABLED", "ENFORCED"]
 WorkflowStepTypeType = Literal["COPY", "CUSTOM", "DELETE", "TAG"]
@@ -115,6 +145,7 @@ ServiceName = Literal[
     "autoscaling-plans",
     "backup",
     "backup-gateway",
+    "backupstorage",
     "batch",
     "billingconductor",
     "braket",
@@ -125,6 +156,7 @@ ServiceName = Literal[
     "chime-sdk-media-pipelines",
     "chime-sdk-meetings",
     "chime-sdk-messaging",
+    "chime-sdk-voice",
     "cloud9",
     "cloudcontrol",
     "clouddirectory",
@@ -156,7 +188,9 @@ ServiceName = Literal[
     "connect",
     "connect-contact-lens",
     "connectcampaigns",
+    "connectcases",
     "connectparticipant",
+    "controltower",
     "cur",
     "customer-profiles",
     "databrew",
@@ -227,6 +261,7 @@ ServiceName = Literal[
     "iot",
     "iot-data",
     "iot-jobs-data",
+    "iot-roborunner",
     "iot1click-devices",
     "iot1click-projects",
     "iotanalytics",
@@ -234,6 +269,7 @@ ServiceName = Literal[
     "iotevents",
     "iotevents-data",
     "iotfleethub",
+    "iotfleetwise",
     "iotsecuretunneling",
     "iotsitewise",
     "iotthingsgraph",
@@ -260,6 +296,7 @@ ServiceName = Literal[
     "lexv2-models",
     "lexv2-runtime",
     "license-manager",
+    "license-manager-user-subscriptions",
     "lightsail",
     "location",
     "logs",
@@ -288,6 +325,7 @@ ServiceName = Literal[
     "mgn",
     "migration-hub-refactor-spaces",
     "migrationhub-config",
+    "migrationhuborchestrator",
     "migrationhubstrategy",
     "mobile",
     "mq",
@@ -313,6 +351,7 @@ ServiceName = Literal[
     "pinpoint-sms-voice-v2",
     "polly",
     "pricing",
+    "privatenetworks",
     "proton",
     "qldb",
     "qldb-session",
@@ -326,6 +365,7 @@ ServiceName = Literal[
     "redshift-serverless",
     "rekognition",
     "resiliencehub",
+    "resource-explorer-2",
     "resource-groups",
     "resourcegroupstaggingapi",
     "robomaker",
@@ -346,6 +386,7 @@ ServiceName = Literal[
     "sagemaker-featurestore-runtime",
     "sagemaker-runtime",
     "savingsplans",
+    "scheduler",
     "schemas",
     "sdb",
     "secretsmanager",
@@ -368,6 +409,7 @@ ServiceName = Literal[
     "ssm",
     "ssm-contacts",
     "ssm-incidents",
+    "ssm-sap",
     "sso",
     "sso-admin",
     "sso-oidc",
@@ -375,6 +417,7 @@ ServiceName = Literal[
     "storagegateway",
     "sts",
     "support",
+    "support-app",
     "swf",
     "synthetics",
     "textract",
@@ -411,7 +454,11 @@ ResourceServiceName = Literal[
 ]
 PaginatorName = Literal[
     "list_accesses",
+    "list_agreements",
+    "list_certificates",
+    "list_connectors",
     "list_executions",
+    "list_profiles",
     "list_security_policies",
     "list_servers",
     "list_tags_for_resource",
@@ -428,6 +475,7 @@ RegionName = Literal[
     "ap-south-1",
     "ap-southeast-1",
     "ap-southeast-2",
+    "ap-southeast-3",
     "ca-central-1",
     "eu-central-1",
     "eu-north-1",
