@@ -11,7 +11,11 @@ Usage::
     from mypy_boto3_transfer.client import TransferClient
     from mypy_boto3_transfer.paginator import (
         ListAccessesPaginator,
+        ListAgreementsPaginator,
+        ListCertificatesPaginator,
+        ListConnectorsPaginator,
         ListExecutionsPaginator,
+        ListProfilesPaginator,
         ListSecurityPoliciesPaginator,
         ListServersPaginator,
         ListTagsForResourcePaginator,
@@ -23,7 +27,11 @@ Usage::
     client: TransferClient = session.client("transfer")
 
     list_accesses_paginator: ListAccessesPaginator = client.get_paginator("list_accesses")
+    list_agreements_paginator: ListAgreementsPaginator = client.get_paginator("list_agreements")
+    list_certificates_paginator: ListCertificatesPaginator = client.get_paginator("list_certificates")
+    list_connectors_paginator: ListConnectorsPaginator = client.get_paginator("list_connectors")
     list_executions_paginator: ListExecutionsPaginator = client.get_paginator("list_executions")
+    list_profiles_paginator: ListProfilesPaginator = client.get_paginator("list_profiles")
     list_security_policies_paginator: ListSecurityPoliciesPaginator = client.get_paginator("list_security_policies")
     list_servers_paginator: ListServersPaginator = client.get_paginator("list_servers")
     list_tags_for_resource_paginator: ListTagsForResourcePaginator = client.get_paginator("list_tags_for_resource")
@@ -35,9 +43,14 @@ from typing import Generic, Iterator, TypeVar
 
 from botocore.paginate import PageIterator, Paginator
 
+from .literals import ProfileTypeType
 from .type_defs import (
     ListAccessesResponseTypeDef,
+    ListAgreementsResponseTypeDef,
+    ListCertificatesResponseTypeDef,
+    ListConnectorsResponseTypeDef,
     ListExecutionsResponseTypeDef,
+    ListProfilesResponseTypeDef,
     ListSecurityPoliciesResponseTypeDef,
     ListServersResponseTypeDef,
     ListTagsForResourceResponseTypeDef,
@@ -48,7 +61,11 @@ from .type_defs import (
 
 __all__ = (
     "ListAccessesPaginator",
+    "ListAgreementsPaginator",
+    "ListCertificatesPaginator",
+    "ListConnectorsPaginator",
     "ListExecutionsPaginator",
+    "ListProfilesPaginator",
     "ListSecurityPoliciesPaginator",
     "ListServersPaginator",
     "ListTagsForResourcePaginator",
@@ -82,6 +99,51 @@ class ListAccessesPaginator(Paginator):
         """
 
 
+class ListAgreementsPaginator(Paginator):
+    """
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Paginator.ListAgreements)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/paginators/#listagreementspaginator)
+    """
+
+    def paginate(
+        self, *, ServerId: str, PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[ListAgreementsResponseTypeDef]:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Paginator.ListAgreements.paginate)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/paginators/#listagreementspaginator)
+        """
+
+
+class ListCertificatesPaginator(Paginator):
+    """
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Paginator.ListCertificates)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/paginators/#listcertificatespaginator)
+    """
+
+    def paginate(
+        self, *, PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[ListCertificatesResponseTypeDef]:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Paginator.ListCertificates.paginate)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/paginators/#listcertificatespaginator)
+        """
+
+
+class ListConnectorsPaginator(Paginator):
+    """
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Paginator.ListConnectors)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/paginators/#listconnectorspaginator)
+    """
+
+    def paginate(
+        self, *, PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[ListConnectorsResponseTypeDef]:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Paginator.ListConnectors.paginate)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/paginators/#listconnectorspaginator)
+        """
+
+
 class ListExecutionsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Paginator.ListExecutions)
@@ -97,6 +159,21 @@ class ListExecutionsPaginator(Paginator):
         """
 
 
+class ListProfilesPaginator(Paginator):
+    """
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Paginator.ListProfiles)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/paginators/#listprofilespaginator)
+    """
+
+    def paginate(
+        self, *, ProfileType: ProfileTypeType = ..., PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[ListProfilesResponseTypeDef]:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Paginator.ListProfiles.paginate)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/paginators/#listprofilespaginator)
+        """
+
+
 class ListSecurityPoliciesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Paginator.ListSecurityPolicies)
