@@ -6,31 +6,45 @@ Type annotations for transfer service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_transfer.type_defs import HomeDirectoryMapEntryTypeDef
+    from mypy_boto3_transfer.type_defs import As2ConnectorConfigTypeDef
 
-    data: HomeDirectoryMapEntryTypeDef = {...}
+    data: As2ConnectorConfigTypeDef = {...}
     ```
 """
 import sys
 from datetime import datetime
-from typing import Dict, List, Sequence
+from typing import Dict, List, Sequence, Union
 
 from .literals import (
+    AgreementStatusTypeType,
+    CertificateStatusTypeType,
+    CertificateTypeType,
+    CertificateUsageTypeType,
+    CompressionEnumType,
     CustomStepStatusType,
     DomainType,
+    EncryptionAlgType,
     EndpointTypeType,
     ExecutionErrorTypeType,
     ExecutionStatusType,
     HomeDirectoryTypeType,
     IdentityProviderTypeType,
+    MdnResponseType,
+    MdnSigningAlgType,
     OverwriteExistingType,
+    ProfileTypeType,
     ProtocolType,
     SetStatOptionType,
+    SigningAlgType,
     StateType,
     TlsSessionResumptionModeType,
     WorkflowStepTypeType,
 )
 
+if sys.version_info >= (3, 9):
+    from typing import Literal
+else:
+    from typing_extensions import Literal
 if sys.version_info >= (3, 9):
     from typing import TypedDict
 else:
@@ -38,22 +52,33 @@ else:
 
 
 __all__ = (
+    "As2ConnectorConfigTypeDef",
     "HomeDirectoryMapEntryTypeDef",
     "PosixProfileTypeDef",
     "ResponseMetadataTypeDef",
+    "TagTypeDef",
     "EndpointDetailsTypeDef",
     "IdentityProviderDetailsTypeDef",
     "ProtocolDetailsTypeDef",
-    "TagTypeDef",
     "CustomStepDetailsTypeDef",
     "DeleteAccessRequestRequestTypeDef",
+    "DeleteAgreementRequestRequestTypeDef",
+    "DeleteCertificateRequestRequestTypeDef",
+    "DeleteConnectorRequestRequestTypeDef",
+    "DeleteHostKeyRequestRequestTypeDef",
+    "DeleteProfileRequestRequestTypeDef",
     "DeleteServerRequestRequestTypeDef",
     "DeleteSshPublicKeyRequestRequestTypeDef",
     "DeleteStepDetailsTypeDef",
     "DeleteUserRequestRequestTypeDef",
     "DeleteWorkflowRequestRequestTypeDef",
     "DescribeAccessRequestRequestTypeDef",
+    "DescribeAgreementRequestRequestTypeDef",
+    "DescribeCertificateRequestRequestTypeDef",
+    "DescribeConnectorRequestRequestTypeDef",
     "DescribeExecutionRequestRequestTypeDef",
+    "DescribeHostKeyRequestRequestTypeDef",
+    "DescribeProfileRequestRequestTypeDef",
     "DescribeSecurityPolicyRequestRequestTypeDef",
     "DescribedSecurityPolicyTypeDef",
     "DescribeServerRequestRequestTypeDef",
@@ -70,7 +95,17 @@ __all__ = (
     "PaginatorConfigTypeDef",
     "ListAccessesRequestRequestTypeDef",
     "ListedAccessTypeDef",
+    "ListAgreementsRequestRequestTypeDef",
+    "ListedAgreementTypeDef",
+    "ListCertificatesRequestRequestTypeDef",
+    "ListedCertificateTypeDef",
+    "ListConnectorsRequestRequestTypeDef",
+    "ListedConnectorTypeDef",
     "ListExecutionsRequestRequestTypeDef",
+    "ListHostKeysRequestRequestTypeDef",
+    "ListedHostKeyTypeDef",
+    "ListProfilesRequestRequestTypeDef",
+    "ListedProfileTypeDef",
     "ListSecurityPoliciesRequestRequestTypeDef",
     "ListServersRequestRequestTypeDef",
     "ListedServerTypeDef",
@@ -82,27 +117,54 @@ __all__ = (
     "S3TagTypeDef",
     "SendWorkflowStepStateRequestRequestTypeDef",
     "UserDetailsTypeDef",
+    "StartFileTransferRequestRequestTypeDef",
     "StartServerRequestRequestTypeDef",
     "StopServerRequestRequestTypeDef",
     "TestIdentityProviderRequestRequestTypeDef",
     "UntagResourceRequestRequestTypeDef",
+    "UpdateAgreementRequestRequestTypeDef",
+    "UpdateCertificateRequestRequestTypeDef",
+    "UpdateHostKeyRequestRequestTypeDef",
+    "UpdateProfileRequestRequestTypeDef",
     "WorkflowDetailTypeDef",
+    "UpdateConnectorRequestRequestTypeDef",
     "CreateAccessRequestRequestTypeDef",
     "DescribedAccessTypeDef",
     "UpdateAccessRequestRequestTypeDef",
     "UpdateUserRequestRequestTypeDef",
     "CreateAccessResponseTypeDef",
+    "CreateAgreementResponseTypeDef",
+    "CreateConnectorResponseTypeDef",
+    "CreateProfileResponseTypeDef",
     "CreateServerResponseTypeDef",
     "CreateUserResponseTypeDef",
     "CreateWorkflowResponseTypeDef",
     "EmptyResponseMetadataTypeDef",
+    "ImportCertificateResponseTypeDef",
+    "ImportHostKeyResponseTypeDef",
     "ImportSshPublicKeyResponseTypeDef",
     "ListSecurityPoliciesResponseTypeDef",
+    "StartFileTransferResponseTypeDef",
     "TestIdentityProviderResponseTypeDef",
     "UpdateAccessResponseTypeDef",
+    "UpdateAgreementResponseTypeDef",
+    "UpdateCertificateResponseTypeDef",
+    "UpdateConnectorResponseTypeDef",
+    "UpdateHostKeyResponseTypeDef",
+    "UpdateProfileResponseTypeDef",
     "UpdateServerResponseTypeDef",
     "UpdateUserResponseTypeDef",
+    "CreateAgreementRequestRequestTypeDef",
+    "CreateConnectorRequestRequestTypeDef",
+    "CreateProfileRequestRequestTypeDef",
     "CreateUserRequestRequestTypeDef",
+    "DescribedAgreementTypeDef",
+    "DescribedCertificateTypeDef",
+    "DescribedConnectorTypeDef",
+    "DescribedHostKeyTypeDef",
+    "DescribedProfileTypeDef",
+    "ImportCertificateRequestRequestTypeDef",
+    "ImportHostKeyRequestRequestTypeDef",
     "ListTagsForResourceResponseTypeDef",
     "TagResourceRequestRequestTypeDef",
     "DescribeSecurityPolicyResponseTypeDef",
@@ -113,13 +175,22 @@ __all__ = (
     "FileLocationTypeDef",
     "InputFileLocationTypeDef",
     "ListAccessesRequestListAccessesPaginateTypeDef",
+    "ListAgreementsRequestListAgreementsPaginateTypeDef",
+    "ListCertificatesRequestListCertificatesPaginateTypeDef",
+    "ListConnectorsRequestListConnectorsPaginateTypeDef",
     "ListExecutionsRequestListExecutionsPaginateTypeDef",
+    "ListProfilesRequestListProfilesPaginateTypeDef",
     "ListSecurityPoliciesRequestListSecurityPoliciesPaginateTypeDef",
     "ListServersRequestListServersPaginateTypeDef",
     "ListTagsForResourceRequestListTagsForResourcePaginateTypeDef",
     "ListUsersRequestListUsersPaginateTypeDef",
     "ListWorkflowsRequestListWorkflowsPaginateTypeDef",
     "ListAccessesResponseTypeDef",
+    "ListAgreementsResponseTypeDef",
+    "ListCertificatesResponseTypeDef",
+    "ListConnectorsResponseTypeDef",
+    "ListHostKeysResponseTypeDef",
+    "ListProfilesResponseTypeDef",
     "ListServersResponseTypeDef",
     "ListUsersResponseTypeDef",
     "ListWorkflowsResponseTypeDef",
@@ -127,6 +198,11 @@ __all__ = (
     "ServiceMetadataTypeDef",
     "WorkflowDetailsTypeDef",
     "DescribeAccessResponseTypeDef",
+    "DescribeAgreementResponseTypeDef",
+    "DescribeCertificateResponseTypeDef",
+    "DescribeConnectorResponseTypeDef",
+    "DescribeHostKeyResponseTypeDef",
+    "DescribeProfileResponseTypeDef",
     "DescribeUserResponseTypeDef",
     "ExecutionResultsTypeDef",
     "CopyStepDetailsTypeDef",
@@ -144,6 +220,21 @@ __all__ = (
     "DescribeWorkflowResponseTypeDef",
 )
 
+As2ConnectorConfigTypeDef = TypedDict(
+    "As2ConnectorConfigTypeDef",
+    {
+        "LocalProfileId": str,
+        "PartnerProfileId": str,
+        "MessageSubject": str,
+        "Compression": CompressionEnumType,
+        "EncryptionAlgorithm": EncryptionAlgType,
+        "SigningAlgorithm": SigningAlgType,
+        "MdnSigningAlgorithm": MdnSigningAlgType,
+        "MdnResponse": MdnResponseType,
+    },
+    total=False,
+)
+
 HomeDirectoryMapEntryTypeDef = TypedDict(
     "HomeDirectoryMapEntryTypeDef",
     {
@@ -183,6 +274,14 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
+TagTypeDef = TypedDict(
+    "TagTypeDef",
+    {
+        "Key": str,
+        "Value": str,
+    },
+)
+
 EndpointDetailsTypeDef = TypedDict(
     "EndpointDetailsTypeDef",
     {
@@ -212,18 +311,11 @@ ProtocolDetailsTypeDef = TypedDict(
         "PassiveIp": str,
         "TlsSessionResumptionMode": TlsSessionResumptionModeType,
         "SetStatOption": SetStatOptionType,
+        "As2Transports": Sequence[Literal["HTTP"]],
     },
     total=False,
 )
 
-TagTypeDef = TypedDict(
-    "TagTypeDef",
-    {
-        "Key": str,
-        "Value": str,
-    },
-)
-
 CustomStepDetailsTypeDef = TypedDict(
     "CustomStepDetailsTypeDef",
     {
@@ -243,6 +335,43 @@ DeleteAccessRequestRequestTypeDef = TypedDict(
     },
 )
 
+DeleteAgreementRequestRequestTypeDef = TypedDict(
+    "DeleteAgreementRequestRequestTypeDef",
+    {
+        "AgreementId": str,
+        "ServerId": str,
+    },
+)
+
+DeleteCertificateRequestRequestTypeDef = TypedDict(
+    "DeleteCertificateRequestRequestTypeDef",
+    {
+        "CertificateId": str,
+    },
+)
+
+DeleteConnectorRequestRequestTypeDef = TypedDict(
+    "DeleteConnectorRequestRequestTypeDef",
+    {
+        "ConnectorId": str,
+    },
+)
+
+DeleteHostKeyRequestRequestTypeDef = TypedDict(
+    "DeleteHostKeyRequestRequestTypeDef",
+    {
+        "ServerId": str,
+        "HostKeyId": str,
+    },
+)
+
+DeleteProfileRequestRequestTypeDef = TypedDict(
+    "DeleteProfileRequestRequestTypeDef",
+    {
+        "ProfileId": str,
+    },
+)
+
 DeleteServerRequestRequestTypeDef = TypedDict(
     "DeleteServerRequestRequestTypeDef",
     {
@@ -291,6 +420,28 @@ DescribeAccessRequestRequestTypeDef = TypedDict(
     },
 )
 
+DescribeAgreementRequestRequestTypeDef = TypedDict(
+    "DescribeAgreementRequestRequestTypeDef",
+    {
+        "AgreementId": str,
+        "ServerId": str,
+    },
+)
+
+DescribeCertificateRequestRequestTypeDef = TypedDict(
+    "DescribeCertificateRequestRequestTypeDef",
+    {
+        "CertificateId": str,
+    },
+)
+
+DescribeConnectorRequestRequestTypeDef = TypedDict(
+    "DescribeConnectorRequestRequestTypeDef",
+    {
+        "ConnectorId": str,
+    },
+)
+
 DescribeExecutionRequestRequestTypeDef = TypedDict(
     "DescribeExecutionRequestRequestTypeDef",
     {
@@ -299,6 +450,21 @@ DescribeExecutionRequestRequestTypeDef = TypedDict(
     },
 )
 
+DescribeHostKeyRequestRequestTypeDef = TypedDict(
+    "DescribeHostKeyRequestRequestTypeDef",
+    {
+        "ServerId": str,
+        "HostKeyId": str,
+    },
+)
+
+DescribeProfileRequestRequestTypeDef = TypedDict(
+    "DescribeProfileRequestRequestTypeDef",
+    {
+        "ProfileId": str,
+    },
+)
+
 DescribeSecurityPolicyRequestRequestTypeDef = TypedDict(
     "DescribeSecurityPolicyRequestRequestTypeDef",
     {
@@ -469,6 +635,85 @@ ListedAccessTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredListAgreementsRequestRequestTypeDef = TypedDict(
+    "_RequiredListAgreementsRequestRequestTypeDef",
+    {
+        "ServerId": str,
+    },
+)
+_OptionalListAgreementsRequestRequestTypeDef = TypedDict(
+    "_OptionalListAgreementsRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListAgreementsRequestRequestTypeDef(
+    _RequiredListAgreementsRequestRequestTypeDef, _OptionalListAgreementsRequestRequestTypeDef
+):
+    pass
+
+
+ListedAgreementTypeDef = TypedDict(
+    "ListedAgreementTypeDef",
+    {
+        "Arn": str,
+        "AgreementId": str,
+        "Description": str,
+        "Status": AgreementStatusTypeType,
+        "ServerId": str,
+        "LocalProfileId": str,
+        "PartnerProfileId": str,
+    },
+    total=False,
+)
+
+ListCertificatesRequestRequestTypeDef = TypedDict(
+    "ListCertificatesRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+ListedCertificateTypeDef = TypedDict(
+    "ListedCertificateTypeDef",
+    {
+        "Arn": str,
+        "CertificateId": str,
+        "Usage": CertificateUsageTypeType,
+        "Status": CertificateStatusTypeType,
+        "ActiveDate": datetime,
+        "InactiveDate": datetime,
+        "Type": CertificateTypeType,
+        "Description": str,
+    },
+    total=False,
+)
+
+ListConnectorsRequestRequestTypeDef = TypedDict(
+    "ListConnectorsRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+ListedConnectorTypeDef = TypedDict(
+    "ListedConnectorTypeDef",
+    {
+        "Arn": str,
+        "ConnectorId": str,
+        "Url": str,
+    },
+    total=False,
+)
+
 _RequiredListExecutionsRequestRequestTypeDef = TypedDict(
     "_RequiredListExecutionsRequestRequestTypeDef",
     {
@@ -491,6 +736,72 @@ class ListExecutionsRequestRequestTypeDef(
     pass
 
 
+_RequiredListHostKeysRequestRequestTypeDef = TypedDict(
+    "_RequiredListHostKeysRequestRequestTypeDef",
+    {
+        "ServerId": str,
+    },
+)
+_OptionalListHostKeysRequestRequestTypeDef = TypedDict(
+    "_OptionalListHostKeysRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListHostKeysRequestRequestTypeDef(
+    _RequiredListHostKeysRequestRequestTypeDef, _OptionalListHostKeysRequestRequestTypeDef
+):
+    pass
+
+
+_RequiredListedHostKeyTypeDef = TypedDict(
+    "_RequiredListedHostKeyTypeDef",
+    {
+        "Arn": str,
+    },
+)
+_OptionalListedHostKeyTypeDef = TypedDict(
+    "_OptionalListedHostKeyTypeDef",
+    {
+        "HostKeyId": str,
+        "Fingerprint": str,
+        "Description": str,
+        "Type": str,
+        "DateImported": datetime,
+    },
+    total=False,
+)
+
+
+class ListedHostKeyTypeDef(_RequiredListedHostKeyTypeDef, _OptionalListedHostKeyTypeDef):
+    pass
+
+
+ListProfilesRequestRequestTypeDef = TypedDict(
+    "ListProfilesRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+        "ProfileType": ProfileTypeType,
+    },
+    total=False,
+)
+
+ListedProfileTypeDef = TypedDict(
+    "ListedProfileTypeDef",
+    {
+        "Arn": str,
+        "ProfileId": str,
+        "As2Id": str,
+        "ProfileType": ProfileTypeType,
+    },
+    total=False,
+)
+
 ListSecurityPoliciesRequestRequestTypeDef = TypedDict(
     "ListSecurityPoliciesRequestRequestTypeDef",
     {
@@ -659,6 +970,14 @@ class UserDetailsTypeDef(_RequiredUserDetailsTypeDef, _OptionalUserDetailsTypeDe
     pass
 
 
+StartFileTransferRequestRequestTypeDef = TypedDict(
+    "StartFileTransferRequestRequestTypeDef",
+    {
+        "ConnectorId": str,
+        "SendFilePaths": Sequence[str],
+    },
+)
+
 StartServerRequestRequestTypeDef = TypedDict(
     "StartServerRequestRequestTypeDef",
     {
@@ -706,6 +1025,86 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
+_RequiredUpdateAgreementRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateAgreementRequestRequestTypeDef",
+    {
+        "AgreementId": str,
+        "ServerId": str,
+    },
+)
+_OptionalUpdateAgreementRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateAgreementRequestRequestTypeDef",
+    {
+        "Description": str,
+        "Status": AgreementStatusTypeType,
+        "LocalProfileId": str,
+        "PartnerProfileId": str,
+        "BaseDirectory": str,
+        "AccessRole": str,
+    },
+    total=False,
+)
+
+
+class UpdateAgreementRequestRequestTypeDef(
+    _RequiredUpdateAgreementRequestRequestTypeDef, _OptionalUpdateAgreementRequestRequestTypeDef
+):
+    pass
+
+
+_RequiredUpdateCertificateRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateCertificateRequestRequestTypeDef",
+    {
+        "CertificateId": str,
+    },
+)
+_OptionalUpdateCertificateRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateCertificateRequestRequestTypeDef",
+    {
+        "ActiveDate": Union[datetime, str],
+        "InactiveDate": Union[datetime, str],
+        "Description": str,
+    },
+    total=False,
+)
+
+
+class UpdateCertificateRequestRequestTypeDef(
+    _RequiredUpdateCertificateRequestRequestTypeDef, _OptionalUpdateCertificateRequestRequestTypeDef
+):
+    pass
+
+
+UpdateHostKeyRequestRequestTypeDef = TypedDict(
+    "UpdateHostKeyRequestRequestTypeDef",
+    {
+        "ServerId": str,
+        "HostKeyId": str,
+        "Description": str,
+    },
+)
+
+_RequiredUpdateProfileRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateProfileRequestRequestTypeDef",
+    {
+        "ProfileId": str,
+    },
+)
+_OptionalUpdateProfileRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateProfileRequestRequestTypeDef",
+    {
+        "CertificateIds": Sequence[str],
+    },
+    total=False,
+)
+
+
+class UpdateProfileRequestRequestTypeDef(
+    _RequiredUpdateProfileRequestRequestTypeDef, _OptionalUpdateProfileRequestRequestTypeDef
+):
+    pass
+
+
 WorkflowDetailTypeDef = TypedDict(
     "WorkflowDetailTypeDef",
     {
@@ -714,6 +1113,30 @@ WorkflowDetailTypeDef = TypedDict(
     },
 )
 
+_RequiredUpdateConnectorRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateConnectorRequestRequestTypeDef",
+    {
+        "ConnectorId": str,
+    },
+)
+_OptionalUpdateConnectorRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateConnectorRequestRequestTypeDef",
+    {
+        "Url": str,
+        "As2Config": As2ConnectorConfigTypeDef,
+        "AccessRole": str,
+        "LoggingRole": str,
+    },
+    total=False,
+)
+
+
+class UpdateConnectorRequestRequestTypeDef(
+    _RequiredUpdateConnectorRequestRequestTypeDef, _OptionalUpdateConnectorRequestRequestTypeDef
+):
+    pass
+
+
 _RequiredCreateAccessRequestRequestTypeDef = TypedDict(
     "_RequiredCreateAccessRequestRequestTypeDef",
     {
@@ -818,6 +1241,30 @@ CreateAccessResponseTypeDef = TypedDict(
     },
 )
 
+CreateAgreementResponseTypeDef = TypedDict(
+    "CreateAgreementResponseTypeDef",
+    {
+        "AgreementId": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+CreateConnectorResponseTypeDef = TypedDict(
+    "CreateConnectorResponseTypeDef",
+    {
+        "ConnectorId": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+CreateProfileResponseTypeDef = TypedDict(
+    "CreateProfileResponseTypeDef",
+    {
+        "ProfileId": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 CreateServerResponseTypeDef = TypedDict(
     "CreateServerResponseTypeDef",
     {
@@ -850,6 +1297,23 @@ EmptyResponseMetadataTypeDef = TypedDict(
     },
 )
 
+ImportCertificateResponseTypeDef = TypedDict(
+    "ImportCertificateResponseTypeDef",
+    {
+        "CertificateId": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ImportHostKeyResponseTypeDef = TypedDict(
+    "ImportHostKeyResponseTypeDef",
+    {
+        "ServerId": str,
+        "HostKeyId": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 ImportSshPublicKeyResponseTypeDef = TypedDict(
     "ImportSshPublicKeyResponseTypeDef",
     {
@@ -869,6 +1333,14 @@ ListSecurityPoliciesResponseTypeDef = TypedDict(
     },
 )
 
+StartFileTransferResponseTypeDef = TypedDict(
+    "StartFileTransferResponseTypeDef",
+    {
+        "TransferId": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 TestIdentityProviderResponseTypeDef = TypedDict(
     "TestIdentityProviderResponseTypeDef",
     {
@@ -889,6 +1361,47 @@ UpdateAccessResponseTypeDef = TypedDict(
     },
 )
 
+UpdateAgreementResponseTypeDef = TypedDict(
+    "UpdateAgreementResponseTypeDef",
+    {
+        "AgreementId": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+UpdateCertificateResponseTypeDef = TypedDict(
+    "UpdateCertificateResponseTypeDef",
+    {
+        "CertificateId": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+UpdateConnectorResponseTypeDef = TypedDict(
+    "UpdateConnectorResponseTypeDef",
+    {
+        "ConnectorId": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+UpdateHostKeyResponseTypeDef = TypedDict(
+    "UpdateHostKeyResponseTypeDef",
+    {
+        "ServerId": str,
+        "HostKeyId": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+UpdateProfileResponseTypeDef = TypedDict(
+    "UpdateProfileResponseTypeDef",
+    {
+        "ProfileId": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 UpdateServerResponseTypeDef = TypedDict(
     "UpdateServerResponseTypeDef",
     {
@@ -906,6 +1419,80 @@ UpdateUserResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredCreateAgreementRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateAgreementRequestRequestTypeDef",
+    {
+        "ServerId": str,
+        "LocalProfileId": str,
+        "PartnerProfileId": str,
+        "BaseDirectory": str,
+        "AccessRole": str,
+    },
+)
+_OptionalCreateAgreementRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateAgreementRequestRequestTypeDef",
+    {
+        "Description": str,
+        "Status": AgreementStatusTypeType,
+        "Tags": Sequence[TagTypeDef],
+    },
+    total=False,
+)
+
+
+class CreateAgreementRequestRequestTypeDef(
+    _RequiredCreateAgreementRequestRequestTypeDef, _OptionalCreateAgreementRequestRequestTypeDef
+):
+    pass
+
+
+_RequiredCreateConnectorRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateConnectorRequestRequestTypeDef",
+    {
+        "Url": str,
+        "As2Config": As2ConnectorConfigTypeDef,
+        "AccessRole": str,
+    },
+)
+_OptionalCreateConnectorRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateConnectorRequestRequestTypeDef",
+    {
+        "LoggingRole": str,
+        "Tags": Sequence[TagTypeDef],
+    },
+    total=False,
+)
+
+
+class CreateConnectorRequestRequestTypeDef(
+    _RequiredCreateConnectorRequestRequestTypeDef, _OptionalCreateConnectorRequestRequestTypeDef
+):
+    pass
+
+
+_RequiredCreateProfileRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateProfileRequestRequestTypeDef",
+    {
+        "As2Id": str,
+        "ProfileType": ProfileTypeType,
+    },
+)
+_OptionalCreateProfileRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateProfileRequestRequestTypeDef",
+    {
+        "CertificateIds": Sequence[str],
+        "Tags": Sequence[TagTypeDef],
+    },
+    total=False,
+)
+
+
+class CreateProfileRequestRequestTypeDef(
+    _RequiredCreateProfileRequestRequestTypeDef, _OptionalCreateProfileRequestRequestTypeDef
+):
+    pass
+
+
 _RequiredCreateUserRequestRequestTypeDef = TypedDict(
     "_RequiredCreateUserRequestRequestTypeDef",
     {
@@ -935,6 +1522,191 @@ class CreateUserRequestRequestTypeDef(
     pass
 
 
+_RequiredDescribedAgreementTypeDef = TypedDict(
+    "_RequiredDescribedAgreementTypeDef",
+    {
+        "Arn": str,
+    },
+)
+_OptionalDescribedAgreementTypeDef = TypedDict(
+    "_OptionalDescribedAgreementTypeDef",
+    {
+        "AgreementId": str,
+        "Description": str,
+        "Status": AgreementStatusTypeType,
+        "ServerId": str,
+        "LocalProfileId": str,
+        "PartnerProfileId": str,
+        "BaseDirectory": str,
+        "AccessRole": str,
+        "Tags": List[TagTypeDef],
+    },
+    total=False,
+)
+
+
+class DescribedAgreementTypeDef(
+    _RequiredDescribedAgreementTypeDef, _OptionalDescribedAgreementTypeDef
+):
+    pass
+
+
+_RequiredDescribedCertificateTypeDef = TypedDict(
+    "_RequiredDescribedCertificateTypeDef",
+    {
+        "Arn": str,
+    },
+)
+_OptionalDescribedCertificateTypeDef = TypedDict(
+    "_OptionalDescribedCertificateTypeDef",
+    {
+        "CertificateId": str,
+        "Usage": CertificateUsageTypeType,
+        "Status": CertificateStatusTypeType,
+        "Certificate": str,
+        "CertificateChain": str,
+        "ActiveDate": datetime,
+        "InactiveDate": datetime,
+        "Serial": str,
+        "NotBeforeDate": datetime,
+        "NotAfterDate": datetime,
+        "Type": CertificateTypeType,
+        "Description": str,
+        "Tags": List[TagTypeDef],
+    },
+    total=False,
+)
+
+
+class DescribedCertificateTypeDef(
+    _RequiredDescribedCertificateTypeDef, _OptionalDescribedCertificateTypeDef
+):
+    pass
+
+
+_RequiredDescribedConnectorTypeDef = TypedDict(
+    "_RequiredDescribedConnectorTypeDef",
+    {
+        "Arn": str,
+    },
+)
+_OptionalDescribedConnectorTypeDef = TypedDict(
+    "_OptionalDescribedConnectorTypeDef",
+    {
+        "ConnectorId": str,
+        "Url": str,
+        "As2Config": As2ConnectorConfigTypeDef,
+        "AccessRole": str,
+        "LoggingRole": str,
+        "Tags": List[TagTypeDef],
+    },
+    total=False,
+)
+
+
+class DescribedConnectorTypeDef(
+    _RequiredDescribedConnectorTypeDef, _OptionalDescribedConnectorTypeDef
+):
+    pass
+
+
+_RequiredDescribedHostKeyTypeDef = TypedDict(
+    "_RequiredDescribedHostKeyTypeDef",
+    {
+        "Arn": str,
+    },
+)
+_OptionalDescribedHostKeyTypeDef = TypedDict(
+    "_OptionalDescribedHostKeyTypeDef",
+    {
+        "HostKeyId": str,
+        "HostKeyFingerprint": str,
+        "Description": str,
+        "Type": str,
+        "DateImported": datetime,
+        "Tags": List[TagTypeDef],
+    },
+    total=False,
+)
+
+
+class DescribedHostKeyTypeDef(_RequiredDescribedHostKeyTypeDef, _OptionalDescribedHostKeyTypeDef):
+    pass
+
+
+_RequiredDescribedProfileTypeDef = TypedDict(
+    "_RequiredDescribedProfileTypeDef",
+    {
+        "Arn": str,
+    },
+)
+_OptionalDescribedProfileTypeDef = TypedDict(
+    "_OptionalDescribedProfileTypeDef",
+    {
+        "ProfileId": str,
+        "ProfileType": ProfileTypeType,
+        "As2Id": str,
+        "CertificateIds": List[str],
+        "Tags": List[TagTypeDef],
+    },
+    total=False,
+)
+
+
+class DescribedProfileTypeDef(_RequiredDescribedProfileTypeDef, _OptionalDescribedProfileTypeDef):
+    pass
+
+
+_RequiredImportCertificateRequestRequestTypeDef = TypedDict(
+    "_RequiredImportCertificateRequestRequestTypeDef",
+    {
+        "Usage": CertificateUsageTypeType,
+        "Certificate": str,
+    },
+)
+_OptionalImportCertificateRequestRequestTypeDef = TypedDict(
+    "_OptionalImportCertificateRequestRequestTypeDef",
+    {
+        "CertificateChain": str,
+        "PrivateKey": str,
+        "ActiveDate": Union[datetime, str],
+        "InactiveDate": Union[datetime, str],
+        "Description": str,
+        "Tags": Sequence[TagTypeDef],
+    },
+    total=False,
+)
+
+
+class ImportCertificateRequestRequestTypeDef(
+    _RequiredImportCertificateRequestRequestTypeDef, _OptionalImportCertificateRequestRequestTypeDef
+):
+    pass
+
+
+_RequiredImportHostKeyRequestRequestTypeDef = TypedDict(
+    "_RequiredImportHostKeyRequestRequestTypeDef",
+    {
+        "ServerId": str,
+        "HostKeyBody": str,
+    },
+)
+_OptionalImportHostKeyRequestRequestTypeDef = TypedDict(
+    "_OptionalImportHostKeyRequestRequestTypeDef",
+    {
+        "Description": str,
+        "Tags": Sequence[TagTypeDef],
+    },
+    total=False,
+)
+
+
+class ImportHostKeyRequestRequestTypeDef(
+    _RequiredImportHostKeyRequestRequestTypeDef, _OptionalImportHostKeyRequestRequestTypeDef
+):
+    pass
+
+
 ListTagsForResourceResponseTypeDef = TypedDict(
     "ListTagsForResourceResponseTypeDef",
     {
@@ -1082,6 +1854,44 @@ class ListAccessesRequestListAccessesPaginateTypeDef(
     pass
 
 
+_RequiredListAgreementsRequestListAgreementsPaginateTypeDef = TypedDict(
+    "_RequiredListAgreementsRequestListAgreementsPaginateTypeDef",
+    {
+        "ServerId": str,
+    },
+)
+_OptionalListAgreementsRequestListAgreementsPaginateTypeDef = TypedDict(
+    "_OptionalListAgreementsRequestListAgreementsPaginateTypeDef",
+    {
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+
+class ListAgreementsRequestListAgreementsPaginateTypeDef(
+    _RequiredListAgreementsRequestListAgreementsPaginateTypeDef,
+    _OptionalListAgreementsRequestListAgreementsPaginateTypeDef,
+):
+    pass
+
+
+ListCertificatesRequestListCertificatesPaginateTypeDef = TypedDict(
+    "ListCertificatesRequestListCertificatesPaginateTypeDef",
+    {
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+ListConnectorsRequestListConnectorsPaginateTypeDef = TypedDict(
+    "ListConnectorsRequestListConnectorsPaginateTypeDef",
+    {
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
 _RequiredListExecutionsRequestListExecutionsPaginateTypeDef = TypedDict(
     "_RequiredListExecutionsRequestListExecutionsPaginateTypeDef",
     {
@@ -1104,6 +1914,15 @@ class ListExecutionsRequestListExecutionsPaginateTypeDef(
     pass
 
 
+ListProfilesRequestListProfilesPaginateTypeDef = TypedDict(
+    "ListProfilesRequestListProfilesPaginateTypeDef",
+    {
+        "ProfileType": ProfileTypeType,
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
 ListSecurityPoliciesRequestListSecurityPoliciesPaginateTypeDef = TypedDict(
     "ListSecurityPoliciesRequestListSecurityPoliciesPaginateTypeDef",
     {
@@ -1182,6 +2001,52 @@ ListAccessesResponseTypeDef = TypedDict(
     },
 )
 
+ListAgreementsResponseTypeDef = TypedDict(
+    "ListAgreementsResponseTypeDef",
+    {
+        "NextToken": str,
+        "Agreements": List[ListedAgreementTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListCertificatesResponseTypeDef = TypedDict(
+    "ListCertificatesResponseTypeDef",
+    {
+        "NextToken": str,
+        "Certificates": List[ListedCertificateTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListConnectorsResponseTypeDef = TypedDict(
+    "ListConnectorsResponseTypeDef",
+    {
+        "NextToken": str,
+        "Connectors": List[ListedConnectorTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListHostKeysResponseTypeDef = TypedDict(
+    "ListHostKeysResponseTypeDef",
+    {
+        "NextToken": str,
+        "ServerId": str,
+        "HostKeys": List[ListedHostKeyTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListProfilesResponseTypeDef = TypedDict(
+    "ListProfilesResponseTypeDef",
+    {
+        "NextToken": str,
+        "Profiles": List[ListedProfileTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 ListServersResponseTypeDef = TypedDict(
     "ListServersResponseTypeDef",
     {
@@ -1231,7 +2096,9 @@ WorkflowDetailsTypeDef = TypedDict(
     "WorkflowDetailsTypeDef",
     {
         "OnUpload": Sequence[WorkflowDetailTypeDef],
+        "OnPartialUpload": Sequence[WorkflowDetailTypeDef],
     },
+    total=False,
 )
 
 DescribeAccessResponseTypeDef = TypedDict(
@@ -1243,6 +2110,46 @@ DescribeAccessResponseTypeDef = TypedDict(
     },
 )
 
+DescribeAgreementResponseTypeDef = TypedDict(
+    "DescribeAgreementResponseTypeDef",
+    {
+        "Agreement": DescribedAgreementTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DescribeCertificateResponseTypeDef = TypedDict(
+    "DescribeCertificateResponseTypeDef",
+    {
+        "Certificate": DescribedCertificateTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DescribeConnectorResponseTypeDef = TypedDict(
+    "DescribeConnectorResponseTypeDef",
+    {
+        "Connector": DescribedConnectorTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DescribeHostKeyResponseTypeDef = TypedDict(
+    "DescribeHostKeyResponseTypeDef",
+    {
+        "HostKey": DescribedHostKeyTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DescribeProfileResponseTypeDef = TypedDict(
+    "DescribeProfileResponseTypeDef",
+    {
+        "Profile": DescribedProfileTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 DescribeUserResponseTypeDef = TypedDict(
     "DescribeUserResponseTypeDef",
     {
